@@ -2,17 +2,19 @@
 use strict;
 $| = 1;
 
-# $Id: mailrpt.pl 858 2005-05-01 22:19:51Z abeltje $
+# $Id$
 use vars qw( $VERSION );
-$VERSION = '0.016';
+$VERSION = '0.017';
 
 use Cwd;
 use File::Spec;
 my $findbin;
 use File::Basename;
-BEGIN { $findbin = dirname $0; }
+BEGIN { $findbin = File::Spec->rel2abs( dirname $0 ); }
 use lib File::Spec->catdir( $findbin, 'lib' );
+use lib File::Spec->catdir( $findbin, 'lib', 'inc' );
 use lib $findbin;
+use lib File::Spec->catdir( $findbin, 'inc' );
 use Test::Smoke::Reporter;
 use Test::Smoke::Mailer;
 use Test::Smoke;
@@ -27,6 +29,9 @@ my %opt = (
     ccp5p_onfail => undef,
     from         => undef,
     mserver      => undef,
+    msport       => 25,
+    msuser       => undef,
+    mspass       => undef,
     v            => undef,
 
     rptfile      => 'mktest.rpt',
@@ -40,7 +45,7 @@ my %opt = (
 
 my $defaults = Test::Smoke::Mailer->config( 'all_defaults' );
 
-my %valid_type = map { $_ => 1 } qw( mail mailx sendmail 
+my %valid_type = map { $_ => 1 } qw( mail mailx sendmail sendemail
                                      Mail::Sendmail MIME::Lite );
 
 =head1 NAME
@@ -74,7 +79,8 @@ Other options can override the settings from the configuration file.
     --to <emailaddresses>    Comma separated list (smokers-reports@perl.org)
     --cc <emailaddresses>    Comma separated list
 
-    -t | --type <type>       mail mailx sendmail Mail::Sendmail [mandatory]
+    -t | --type <type>       mail mailx sendmail sendemail Mail::Sendmail
+                             [mandatory]
 
     --nomail                 Don't send the message
     --report                 Create a report anyway
@@ -94,6 +100,13 @@ no extra options
 
     --from <address>
 
+=item * B<options for> -t sendemail
+
+    --from <address>
+    --mserver <smtpserver>  (localhost)
+    --muser <smtpserverusername>
+    --mpass <smtpserverpassword>
+
 =item * B<options for> -t Mail::Sendmail | MIME::Lite
 
     --from <address>
@@ -112,7 +125,7 @@ GetOptions( \%opt,
     'type|t=s', 'ddir|d=s', 'to=s', 'cc=s', 'bcc=s', 'ccp5p_onfail!',
     'v|verbose=i',
 
-    'from=s', 'mserver=s',
+    'from=s', 'mserver=s', 'msport=i', 'msuser=s', 'mspass=s',
 
     'help|h', 'man',
 
